==> react-tag-chip-1.15.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import PropTypes from 'prop-types';
import CircleX from '@s-ui/react-icons/lib/Circlex';
import cx from 'classnames';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

var Tag = function Tag(_temp) {
  var _ref = _temp === void 0 ? {} : _temp,
      Link = _ref.Link,
      children = _ref.children,
      url = _ref.url,
      rest = _objectWithoutPropertiesLoose(_ref, ["Link", "children", "url"]);

  return url ? /*#__PURE__*/_jsx(Link, _extends({
    href: url
  }, rest, {
    children: children
  })) : /*#__PURE__*/_jsx("span", _extends({}, rest, {
    children: children
  }));
};

var tagChipClassName = function tagChipClassName(_ref2) {
  var isClickable = _ref2.isClickable,
      _ref2$className = _ref2.className,
      className = _ref2$className === void 0 ? null : _ref2$className;
  return cx('sui-TagChip', className, {
    'sui-TagChip-link': isClickable
  });
};

var preventDefaultHandler = function preventDefaultHandler(handler) {
  return function (event) {
    return handler && (event.preventDefault(), event.stopPropagation(), handler.apply());
  };
};

var TagChip = function TagChip(_ref3) {
  var onRequestDelete = _ref3.onRequestDelete,
      onClick = _ref3.onClick,
      label = _ref3.label,
      url = _ref3.link,
      linkFactory = _ref3.linkFactory,
      className = _ref3.className,
      rel = _ref3.rel,
      title = _ref3.title,
      _ref3$icon = _ref3.icon,
      Icon = _ref3$icon === void 0 ? CircleX : _ref3$icon;
  return /*#__PURE__*/_jsxs(Tag, {
    className: tagChipClassName({
      isClickable: url || onClick,
      className: className
    }),
    Link: linkFactory,
    onClick: preventDefaultHandler(onClick),
    rel: rel,
    title: title,
    url: url,
    children: [label, onRequestDelete && /*#__PURE__*/_jsx("span", {
      onClick: preventDefaultHandler(onRequestDelete),
      className: "sui-TagChip-delete",
      children: /*#__PURE__*/_jsx(Icon, {
        svgClass: "sui-TagChip-deleteIcon"
      })
    })]
  });
};

TagChip.displayName = 'TagChip';
TagChip.defaultProps = {
  linkFactory: function linkFactory(_temp2) {
    var _ref4 = _temp2 === void 0 ? {} : _temp2,
        children = _ref4.children,
        rest = _objectWithoutPropertiesLoose(_ref4, ["children"]);

    return /*#__PURE__*/_jsx("a", _extends({}, rest, {
      children: children
    }));
  } // eslint-disable-line

};
export default TagChip;

==> react-tag-chip-1.16.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["Link", "children", "url"],
    _excluded2 = ["children"];
import PropTypes from 'prop-types';
import CircleX from '@s-ui/react-icons/lib/Circlex';
import cx from 'classnames';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

var Tag = function Tag(_temp) {
  var _ref = _temp === void 0 ? {} : _temp,
      Link = _ref.Link,
      children = _ref.children,
      url = _ref.url,
      rest = _objectWithoutPropertiesLoose(_ref, _excluded);

  return url ? /*#__PURE__*/_jsx(Link, _extends({
    href: url
  }, rest, {
    children: children
  })) : /*#__PURE__*/_jsx("span", _extends({}, rest, {
    children: children
  }));
};

var tagChipClassName = function tagChipClassName(_ref2) {
  var isClickable = _ref2.isClickable,
      _ref2$className = _ref2.className,
      className = _ref2$className === void 0 ? null : _ref2$className;
  return cx('sui-TagChip', className, {
    'sui-TagChip-link': isClickable
  });
};

var preventDefaultHandler = function preventDefaultHandler(handler) {
  if (handler === void 0) {
    handler = function handler() {
      return null;
    };
  }

  return function (event) {
    event.preventDefault();
    event.stopPropagation();
    handler.apply();
  };
};

var TagChip = function TagChip(_ref3) {
  var onRequestDelete = _ref3.onRequestDelete,
      onClick = _ref3.onClick,
      label = _ref3.label,
      url = _ref3.link,
      linkFactory = _ref3.linkFactory,
      className = _ref3.className,
      rel = _ref3.rel,
      title = _ref3.title,
      _ref3$icon = _ref3.icon,
      Icon = _ref3$icon === void 0 ? CircleX : _ref3$icon;
  return /*#__PURE__*/_jsxs(Tag, {
    className: tagChipClassName({
      isClickable: url || onClick,
      className: className
    }),
    Link: linkFactory,
    onClick: preventDefaultHandler(onClick),
    rel: rel,
    title: title,
    url: url,
    children: [label, onRequestDelete && /*#__PURE__*/_jsx("span", {
      onClick: preventDefaultHandler(onRequestDelete),
      className: "sui-TagChip-delete",
      children: /*#__PURE__*/_jsx(Icon, {
        svgClass: "sui-TagChip-deleteIcon"
      })
    })]
  });
};

TagChip.displayName = 'TagChip';
TagChip.defaultProps = {
  linkFactory: function linkFactory(_temp2) {
    var _ref4 = _temp2 === void 0 ? {} : _temp2,
        children = _ref4.children,
        rest = _objectWithoutPropertiesLoose(_ref4, _excluded2);

    return /*#__PURE__*/_jsx("a", _extends({}, rest, {
      children: children
    }));
  } // eslint-disable-line

};
export default TagChip;
